/**
 * @fileoverview Portfolio page component for the tattoo studio website.
 * Features a filterable gallery of tattoo artwork with lightbox functionality.
 */

import React, { useState, useEffect, useCallback, memo } from 'react'
import { Dialog } from '@headlessui/react'

/**
 * Portfolio item data structure
 * @typedef {Object} PortfolioItem
 * @property {number} id - Unique identifier
 * @property {string} src - Image source URL
 * @property {string} alt - Image alt text
 * @property {string} artist - Artist name
 * @property {string} style - Tattoo style
 * @property {string} size - Size dimensions
 * @property {string} placement - Body placement
 * @property {string} description - Detailed description
 */

/**
 * Portfolio items data
 * @type {PortfolioItem[]}
 */
const portfolioItems = [
  {
    id: 1,
    src: '/images/portfolio-1.jpg',
    alt: 'Realistic portrait tattoo',
    artist: 'Sarah Chen',
    style: 'Realism',
    size: 'Large (15cm x 20cm)',
    placement: 'Forearm',
    description: 'Detailed black and grey portrait with intricate shading'
  },
  {
    id: 2,
    src: '/images/portfolio-2.jpg',
    alt: 'Neo-traditional flower design',
    artist: 'Marcus Rodriguez',
    style: 'Neo-Traditional',
    size: 'Medium (10cm x 15cm)',
    placement: 'Shoulder',
    description: 'Vibrant neo-traditional rose with bold lines and color'
  },
  {
    id: 3,
    src: '/images/portfolio-3.jpg',
    alt: 'Geometric dot-work mandala',
    artist: 'Elena Volkov',
    style: 'Dot-work',
    size: 'Large (20cm x 20cm)',
    placement: 'Back',
    description: 'Intricate mandala design using precise dot-work technique'
  },
  {
    id: 4,
    src: '/images/portfolio-4.jpg',
    alt: 'Minimalist line art',
    artist: 'James Park',
    style: 'Minimalist',
    size: 'Small (5cm x 8cm)',
    placement: 'Wrist',
    description: 'Clean single-line drawing with elegant simplicity'
  },
  {
    id: 5,
    src: '/images/portfolio-5.jpg',
    alt: 'Traditional Japanese sleeve',
    artist: 'Hiroshi Tanaka',
    style: 'Traditional Japanese',
    size: 'Extra Large (Full Sleeve)',
    placement: 'Arm',
    description: 'Traditional irezumi with koi fish and cherry blossoms'
  },
  {
    id: 6,
    src: '/images/portfolio-6.jpg',
    alt: 'Blackwork tribal design',
    artist: 'Sarah Chen',
    style: 'Blackwork',
    size: 'Medium (12cm x 18cm)',
    placement: 'Leg',
    description: 'Bold tribal-inspired blackwork with modern interpretation'
  }
]

/**
 * Available tattoo style filters
 * @type {string[]}
 */
const styles = ['All', 'Realism', 'Neo-Traditional', 'Dot-work', 'Minimalist', 'Traditional Japanese', 'Blackwork']

/**
 * Portfolio item card component
 * @param {Object} props - Component props
 * @param {PortfolioItem} props.item - Portfolio item data
 * @param {boolean} props.isLoaded - Whether animations should play
 * @param {number} props.index - Item index for staggered animations
 * @param {Function} props.onClick - Click handler function
 * @returns {JSX.Element} Portfolio item card
 */
const PortfolioCard = memo(({ item, isLoaded, index, onClick }) => (
  <div
    className={`group cursor-pointer transform transition-all duration-500 hover:scale-105 ${
      isLoaded ? 'translate-y-0 opacity-100' : 'translate-y-8 opacity-0'
    }`}
    style={{ transitionDelay: `${index * 100}ms` }}
    onClick={onClick}
  >
    <div className="relative overflow-hidden bg-gray-200 rounded-lg aspect-square">
      {/* Placeholder for missing images */}
      <div className="w-full h-full flex items-center justify-center bg-gradient-to-br from-gray-100 to-gray-300">
        <div className="text-center text-gray-500">
          <svg className="w-16 h-16 mx-auto mb-2" fill="currentColor" viewBox="0 0 24 24">
            <path d="M21 19V5c0-1.1-.9-2-2-2H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2zM8.5 13.5l2.5 3.01L14.5 12l4.5 6H5l3.5-4.5z"/>
          </svg>
          <p className="text-xs">{item.style}</p>
        </div>
      </div>
      
      {/* Overlay */}
      <div className="absolute inset-0 bg-black/0 group-hover:bg-black/60 transition-all duration-300 flex items-end">
        <div className="p-4 text-white transform translate-y-full group-hover:translate-y-0 transition-transform duration-300">
          <h3 className="font-serif font-semibold text-lg mb-1">{item.style}</h3>
          <p className="text-sm text-gray-200">by {item.artist}</p>
          <p className="text-xs text-gray-300 mt-1">{item.size}</p>
        </div>
      </div>
    </div>
  </div>
))

/**
 * Portfolio page component
 * @returns {JSX.Element} The portfolio page
 */
function Portfolio() {
  const [selectedStyle, setSelectedStyle] = useState('All')
  const [filteredItems, setFilteredItems] = useState(portfolioItems)
  const [selectedItem, setSelectedItem] = useState(null)
  const [isLightboxOpen, setIsLightboxOpen] = useState(false)
  const [isLoaded, setIsLoaded] = useState(false)

  /**
   * Set loaded state after initial render for animations
   */
  useEffect(() => {
    const timer = setTimeout(() => {
      setIsLoaded(true)
    }, 100)
    
    return () => clearTimeout(timer)
  }, [])

  /**
   * Filter items when style changes
   */
  useEffect(() => {
    if (selectedStyle === 'All') {
      setFilteredItems(portfolioItems)
    } else {
      setFilteredItems(portfolioItems.filter(item => item.style === selectedStyle))
    }
  }, [selectedStyle])

  /**
   * Open lightbox with selected item
   * @param {PortfolioItem} item - The portfolio item to display
   */
  const openLightbox = useCallback((item) => {
    setSelectedItem(item)
    setIsLightboxOpen(true)
  }, [])

  /**
   * Close lightbox
   */
  const closeLightbox = useCallback(() => {
    setIsLightboxOpen(false)
    setSelectedItem(null)
  }, [])

  /**
   * Navigate to the next or previous item in the lightbox
   * @param {'next'|'prev'} direction - Direction to navigate
   */
  const navigateLightbox = useCallback((direction) => {
    if (!selectedItem) return
    
    const currentIndex = filteredItems.findIndex(item => item.id === selectedItem.id)
    let newIndex
    
    if (direction === 'next') {
      newIndex = (currentIndex + 1) % filteredItems.length
    } else {
      newIndex = (currentIndex - 1 + filteredItems.length) % filteredItems.length
    }
    
    setSelectedItem(filteredItems[newIndex])
  }, [filteredItems, selectedItem])

  return (
    <div className="pt-16 lg:pt-20">
      {/* Header */}
      <section className="section-padding py-16 lg:py-24" aria-labelledby="portfolio-heading">
        <div className="container-max">
          <div 
            className={`text-center transform transition-all duration-1000 ${
              isLoaded ? 'translate-y-0 opacity-100' : 'translate-y-8 opacity-0'
            }`}
          >
            <h1 id="portfolio-heading" className="text-4xl md:text-5xl lg:text-6xl font-serif font-bold mb-6">
              Our Portfolio
            </h1>
            <p className="text-lg md:text-xl text-gray-600 max-w-3xl mx-auto">
              Explore our collection of custom tattoos, each piece telling a unique story 
              through masterful artistry and precision.
            </p>
          </div>
        </div>
      </section>

      {/* Filter Tabs */}
      <section className="section-padding pb-8" aria-label="Style filters">
        <div className="container-max">
          <div className="flex flex-wrap justify-center gap-2 md:gap-4" role="group" aria-label="Filter by style">
            {styles.map((style) => (
              <button
                key={style}
                onClick={() => setSelectedStyle(style)}
                className={`px-4 py-2 md:px-6 md:py-3 text-sm md:text-base font-medium tracking-wide uppercase transition-all duration-300 ${
                  selectedStyle === style
                    ? 'bg-black text-white'
                    : 'bg-gray-100 text-black hover:bg-gray-200'
                }`}
                aria-pressed={selectedStyle === style}
              >
                {style}
              </button>
            ))}
          </div>
        </div>
      </section>

      {/* Portfolio Grid */}
      <section className="section-padding pb-20" aria-label="Portfolio gallery">
        <div className="container-max">
          <div 
            className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 lg:gap-8"
            role="list"
            aria-label="Tattoo portfolio items"
          >
            {filteredItems.map((item, index) => (
              <div key={item.id} role="listitem">
                <PortfolioCard
                  item={item}
                  isLoaded={isLoaded}
                  index={index}
                  onClick={() => openLightbox(item)}
                />
              </div>
            ))}
          </div>

          {filteredItems.length === 0 && (
            <div className="text-center py-16">
              <p className="text-lg text-gray-500">No tattoos found for the selected style.</p>
            </div>
          )}
        </div>
      </section>

      {/* Lightbox Modal */}
      <Dialog 
        open={isLightboxOpen} 
        onClose={closeLightbox} 
        className="relative z-50"
      >
        {/* Backdrop */}
        <div className="fixed inset-0 bg-black/90" aria-hidden="true" />
        
        {/* Full-screen container */}
        <div className="fixed inset-0 flex items-center justify-center p-4">
          <Dialog.Panel className="w-full max-w-4xl bg-transparent">
            {selectedItem && (
              <div className="relative">
                {/* Close button */}
                <button 
                  onClick={closeLightbox}
                  className="absolute -top-12 right-0 text-white hover:text-gray-300 transition-colors"
                  aria-label="Close lightbox"
                >
                  <svg className="w-8 h-8" fill="none" stroke="currentColor" viewBox="0 0 24 24" aria-hidden="true">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M6 18L18 6M6 6l12 12" />
                  </svg>
                </button>
                
                {/* Navigation buttons */}
                <div className="absolute inset-y-0 left-0 right-0 flex justify-between items-center pointer-events-none">
                  <button 
                    onClick={() => navigateLightbox('prev')}
                    className="pointer-events-auto -translate-x-16 text-white hover:text-gray-300 transition-colors focus:outline-none focus:ring-2 focus:ring-white focus:ring-opacity-50 rounded-full p-2"
                    aria-label="Previous tattoo"
                  >
                    <svg className="w-10 h-10" fill="none" stroke="currentColor" viewBox="0 0 24 24" aria-hidden="true">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M15 19l-7-7 7-7" />
                    </svg>
                  </button>
                  
                  <button 
                    onClick={() => navigateLightbox('next')}
                    className="pointer-events-auto translate-x-16 text-white hover:text-gray-300 transition-colors focus:outline-none focus:ring-2 focus:ring-white focus:ring-opacity-50 rounded-full p-2"
                    aria-label="Next tattoo"
                  >
                    <svg className="w-10 h-10" fill="none" stroke="currentColor" viewBox="0 0 24 24" aria-hidden="true">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M9 5l7 7-7 7" />
                    </svg>
                  </button>
                </div>
                
                {/* Content */}
                <div className="bg-white rounded-lg overflow-hidden shadow-2xl">
                  <Dialog.Title className="sr-only">
                    {selectedItem.style} Tattoo by {selectedItem.artist}
                  </Dialog.Title>
                  
                  <div className="aspect-video bg-gray-200 flex items-center justify-center">
                    <div className="text-center text-gray-500 p-8">
                      <svg className="w-24 h-24 mx-auto mb-4" fill="currentColor" viewBox="0 0 24 24" aria-hidden="true">
                        <path d="M21 19V5c0-1.1-.9-2-2-2H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2zM8.5 13.5l2.5 3.01L14.5 12l4.5 6H5l3.5-4.5z"/>
                      </svg>
                      <p className="text-lg font-medium">{selectedItem.style} Tattoo</p>
                    </div>
                  </div>
                  
                  <div className="p-6">
                    <div className="flex flex-wrap justify-between items-start mb-4">
                      <div>
                        <h3 className="text-2xl font-serif font-bold">{selectedItem.style}</h3>
                        <p className="text-gray-600">by {selectedItem.artist}</p>
                      </div>
                      <div className="mt-2 md:mt-0 flex flex-wrap gap-2">
                        <span className="inline-block bg-gray-100 rounded-full px-3 py-1 text-sm font-semibold text-gray-700">
                          {selectedItem.size}
                        </span>
                        <span className="inline-block bg-gray-100 rounded-full px-3 py-1 text-sm font-semibold text-gray-700">
                          {selectedItem.placement}
                        </span>
                      </div>
                    </div>
                    
                    <p className="text-gray-700">
                      {selectedItem.description}
                    </p>
                  </div>
                </div>
              </div>
            )}
          </Dialog.Panel>
        </div>
      </Dialog>
    </div>
  )
}

export default Portfolio